@@ -44,7 +44,8 @@ _js_dist = [
         'relative_package_path': 'dash_mp_components.min.js.map',
         'external_url': 'https://unpkg.com/{0}@{2}/{1}/{1}.min.js.map'.format(
             package_name, __name__, __version__),
-        'namespace': package_name
+        'namespace': package_name,
+        'dynamic': True
     }
 ]
 
